@@ -29,6 +29,7 @@ from rrshare.rqUtil import (rq_util_date_today, trade_date_sse,rq_util_get_trade
 from rrshare.rqUtil import (PERIODS, is_trade_time_secs_cn, is_tradeday_and_market_opened)
 from rrshare.rqUtil import (client_pgsql, read_data_from_pg, read_sql_from_pg)
 from rrshare.rqFetch import (stock_code_to_name, fetch_delist_stock, fetch_realtime_price_stock_day_adj)
+from rrshare.rqUtil.rqParameter import START_DATE_COUNT
 
 NList = PERIODS().PERIODS
 N1List = list(map(lambda x: x-1,NList))
@@ -36,35 +37,10 @@ client_rrshare = client_pgsql('rrshare')
 client_rrfactor = client_pgsql('rrfactor')
 
 USERPATH = os.path.expanduser('~')
-print(USERPATH)
 file_path = f'{USERPATH}/.rrsdk/data'
 
 
-def read_stock_day_N_to_pickle(table_name='stock_day_adj_fillna', N=265):
-    """  read large stockday N>250 need 10mins, cron read data save to pickle for speed"""
-    USERPATH = os.path.expanduser('~')
-    print(USERPATH)
-    file_path = f'{USERPATH}/.rrsdk/data'
-    subprocess.run(['mkdir','-p', file_path])
-    #subprocess.run(args=["streamlit","run",f"{USERPATH}/rrshare/rrshare/rqWeb/stock_RS_OH_MA_to_streamlit.py"])
-    file_path_name = f"{file_path}/{table_name}_{N}.pkl"
-    trade_date = rq_util_get_last_tradedate()
-    start_date = rq_util_get_pre_trade_date(trade_date,N)
-    # TODO if file exists ,read and get lasy max date compare with last tradedate
-    # if == pass; else continue
-   
-    df = read_sql_from_pg(start_date=start_date, data=\
-            "trade_date,open,high,low,close,pre_close,vol,amount,\
-            adj_factor,code,pct_chg,avg",table_name=table_name, client=client_rrshare)
-    delist_code = fetch_delist_stock(trade_date)
-    df =df[~df['code'].isin(delist_code)]
-    df.to_pickle(file_path_name)
-    print(df)
-    return df
-    
-       
-
-def stock_RT_HH_MA_pre(table_name='stock_day_adj_fillna', N=255): # ok
+def stock_RT_HH_MA_pre(table_name='stock_day_adj_fillna', N=START_DATE_COUNT): # ok
     """caculate i-1 day rt_ma
        prepare to next day  day rs_OH_ma
        迭代， 只算一次， 速度快。
@@ -82,7 +58,6 @@ def stock_RT_HH_MA_pre(table_name='stock_day_adj_fillna', N=255): # ok
     '''
     file_path_name = f"{file_path}/{table_name}_{N}.pkl"
     df = pd.read_pickle(file_path_name)
-    print(df)
     
     delist_code = fetch_delist_stock(trade_date)
     df =df[~df['code'].isin(delist_code)]
@@ -97,11 +72,9 @@ def stock_RT_HH_MA_pre(table_name='stock_day_adj_fillna', N=255): # ok
     df_fill = df_un_fill.stack().reset_index()
     ma=dict()
     rt=dict()
-    #rs=dict()
     for i in N1List:
         ma[i] = ((df_un_fill['close']*df_un_fill['adj_factor']).rolling(i).mean()/df_un_fill['adj_factor']).unstack()
         rt[i] = df_un_fill['pct_chg'].rolling(i).sum().unstack()
-        #rs[i]= 100*rt[i].unstack(0).rank(axis=1,ascending=True, pct=True).unstack()
     H = (df_un_fill['high']*df_un_fill['adj_factor']).expanding().max()
     HH = (H/df_un_fill['adj_factor']).unstack()
     L = (df_un_fill['low']*df_un_fill['adj_factor']).expanding().min()
@@ -128,7 +101,7 @@ def stock_RT_HH_MA_pre(table_name='stock_day_adj_fillna', N=255): # ok
     return data 
 
 
-def stock_RS_OH_MA_last(table_name='stock_day_adj_fillna', N=255): # ok
+def stock_RS_OH_MA_last(table_name='stock_day_adj_fillna', N=START_DATE_COUNT): # ok
     """caculate i day rt_hh_ma
        prepare to next day  day rs_OH_ma
        迭代， 只算一次， 速度快。
@@ -146,7 +119,6 @@ def stock_RS_OH_MA_last(table_name='stock_day_adj_fillna', N=255): # ok
     """
     file_path_name = f"{file_path}/{table_name}_{N}.pkl"
     df = pd.read_pickle(file_path_name)
-    print(df)
     
     delist_code = fetch_delist_stock(trade_date) 
     df =df[~df['code'].isin(delist_code)]
@@ -213,21 +185,16 @@ def stock_RS_OH_MA_new():
     """
     df = pd.read_sql_table("stock_RT_HH_MA_pre", client_rrfactor)
     #print(df)
-
     df_last_date =str( max(set(list(df['trade_date'].values))))[0:10]
-    print(df_last_date)
-
+    #print(df_last_date)
     today_ = rq_util_date_today().strftime('%Y-%m-%d') 
     print(is_tradeday_and_market_opened())
     trade_date = today_  if is_tradeday_and_market_opened() else rq_util_get_last_tradedate()
     print(trade_date)
     delist_code = fetch_delist_stock(trade_date) 
     df =df[~df['code'].isin(delist_code)]
-    print(trade_date)
-    print(trade_date > df_last_date)
-      
+    #print(trade_date)
     if (trade_date > df_last_date): 
-        #fetch_realtime_price from rqFetch
         df_p = fetch_realtime_price_stock_day_adj()
         print(df_p)
         df_p = df_p.drop(columns =['ts_code', 'trade_date','amount','open'], axis=1)
@@ -241,7 +208,7 @@ def stock_RS_OH_MA_new():
         col_rt_pre =['rt4', 'rt9', 'rt19', 'rt59','rt119', 'rt249']
         col_rt =['rt5', 'rt10', 'rt20', 'rt60','rt120', 'rt250']
         col_ma_dict = dict(zip(col_ma,col_ma_pre))
-        print(col_ma_dict)
+        #print(col_ma_dict)
         col_rt_dict = dict(zip(col_rt, col_rt_pre))
         for  k, v in col_ma_dict.items():
             n = int(k[2:])
@@ -319,6 +286,7 @@ def stock_select_PRS_new():
     save_PRS_to_pg('stock_select_PRS', df, client_rrfactor)
     logging.info(f'\n {df}')
     return df
+  
    
 def save_PRS_to_pg(table_name="",data="", client=client_rrfactor):
     #写入数据，table_name为表名，‘replace’表示如果同名表存在就替换掉
@@ -330,9 +298,9 @@ def save_PRS_to_pg(table_name="",data="", client=client_rrfactor):
             print(e)
 
 
-def update_stock_PRS_day(N=255):
-    stock_RT_HH_MA_pre(N=N)
-    stock_RS_OH_MA_last(N=N)
+def update_stock_PRS_day():
+    stock_RT_HH_MA_pre()
+    stock_RS_OH_MA_last()
     stock_RS_OH_MA()
 
 
@@ -343,9 +311,9 @@ def update_stock_PRS_new():
 
 if __name__ == '__main__':
 
-    update_stock_PRS_day(N=255)
+    update_stock_PRS_day()
     update_stock_PRS_new()
-    pass
+    
    
    
 
