@@ -1,9 +1,7 @@
 from rrshare.rqUpdate.update_stock_day import record_stock_day
 from rrshare.rqUpdate.update_swl_day import record_swl_day
-#from rrshare.rqUpdate.update_swl_rs_valuation import record_swl_rs_valuation
-
 from rrshare.rqUpdate.update_stock_RS_OH_MA import record_stock_PRS, record_stock_PRS_new
-
+from rrshare.rqUpdate.update_swl_RS_OH_MA import record_swl_PRS, record_swl_PRS_new
 
 
 
