@@ -4,7 +4,7 @@ from configparser import ConfigParser
 from rrshare.rqUtil.rqLogs import rq_util_log_info
 from rrshare.rqUtil.config_setting import get_path_file_name
 
-def get_config_ini(section='rrdata',filename='config.ini'):
+def get_config_ini(section='rrshare',filename='config.ini'):
     # create a parser
     parser = ConfigParser()
     # read config file
@@ -20,5 +20,5 @@ def get_config_ini(section='rrdata',filename='config.ini'):
     #rq_util_log_info(db)
     return db
 
-database_uri = get_config_ini('pgsql_rrdata')
+database_uri = get_config_ini('pgsql_rrshare')
 rq_util_log_info(database_uri)
\ No newline at end of file
